<?php
/***************************************************************************
                             digest_upgrade_db.php
                             ---------------------
    begin                : Friday, August 17, 2007
    copyright            : (c) Mark D. Hamill
    email                : mhamill@computer.org

    $Id: $

 ***************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

// Written by Mark D. Hamill, mhamill@computer.org
// This software is designed to work with phpBB Version 2.0.22

// This program is run if you upgrading from version 1.0.17 or earlier. It needs to be run BEFORE installing the other files.

define('IN_PHPBB', true);
$phpbb_root_path = '../';
include($phpbb_root_path . 'extension.inc');
include($phpbb_root_path . 'common.'.$phpEx);
if (file_exists($phpbb_root_path . 'includes/digest_constants.' . $phpEx))
{
	include($phpbb_root_path . 'includes/digest_constants.' . $phpEx); 
}
if (file_exists($phpbb_root_path . 'includes/digest_functions.' . $phpEx))
{
	include($phpbb_root_path . 'includes/digest_functions.' . $phpEx); 
}

define('DIGEST_SETTINGS_TABLE', $table_prefix.'mod_digest_settings');

// Check the version number

if (DIGEST_VERSION == 'DIGEST_VERSION') // This means constant is not set
{
	// If we can query from the DIGEST_SETTINGS_TABLE exists in digest_functions.php then we are running 1.0.17 or higher
	$sql = 'SELECT version FROM ' . DIGEST_SETTINGS_TABLE;
	if ( !($result = $db->sql_query($sql)))
	{
		// Assume this is the first official phpBB release, 1.0.9b
		$major_version = 1;
		$minor_version = 0;
		$micro_version = 9;
	}
	else	
	{
		$row = $db->sql_fetchrow($result);
		$version = explode(".",$row['version']); 
	}
	
}
else // The constant showed up starting in version 1.0.10
{
	$version = explode(".",DIGEST_VERSION);
	$major_version = $version[0];
	$minor_version = $version[1];
	$micro_version = $version[2];
}

if (($major_version == 1) && ($minor_version == 0) && ($micro_version < 13))
{
	// If DBMS is MySQL, add PHTM as an enumerated data type
	if (($dbms == 'mysql') || ($dbms == 'mysql4') || ($dbms == 'mysqli'))
	{
		$sql = 'ALTER TABLE ' . DIGEST_SUBSCRIPTIONS_TABLE . " CHANGE format ENUM('HTML', 'PHTM', 'TEXT') DEFAULT 'HTML'";
		if ( !($result = $db->sql_query($sql)))
		{
			message_die(GENERAL_ERROR, 'Error altering ' . DIGEST_SUBSCRIPTIONS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
		}
	}
}

if (($major_version == 1) && ($minor_version == 0) && ($micro_version < 17))
{
	// 1.0.17 add show_pms column. With the DEFAULT syntax, all existing rows *should* show this value
	$sql = 'ALTER TABLE ' . DIGEST_SUBSCRIPTIONS_TABLE . " ADD show_pms CHAR(3) NOT NULL DEFAULT 'YES'";
	if ( !($result = $db->sql_query($sql)))
	{
		message_die(GENERAL_ERROR, 'Error altering ' . DIGEST_SUBSCRIPTIONS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
	}

	// Assume everyone would like private messages in the digest
	$sql = 'UPDATE ' . DIGEST_SUBSCRIPTIONS_TABLE . " SET show_pms = 'YES'";
	if ( !($result = $db->sql_query($sql)))
	{
		message_die(GENERAL_ERROR, 'Error updating ' . DIGEST_SUBSCRIPTIONS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
	}

	// create the settings table
	$sql='CREATE TABLE ' . DIGEST_SETTINGS_TABLE . " (
	  table_key int(11) NOT NULL default '0',
	  version varchar(10) NOT NULL default '1.0.19',
	  site_url varchar(255) NOT NULL default 'http://www.example.com/phpBB/',
	  autosubscribe_users char(3) NOT NULL default 'NO',
	  autosubscribe_daily varchar(4) NOT NULL default 'DAY',
	  weekly_digest_day int(11) NOT NULL default '0',
	  use_custom_stylesheet char(3) NOT NULL default 'NO',
	  custom_stylesheet_path varchar(255) NOT NULL default 'templates/subSilver/digest_stylesheet.css',
	  date_format varchar(20) NOT NULL default 'd M Y h:i A',
	  server_display_date varchar(20) NOT NULL default 'm/d/Y',
	  html_encoding varchar(20) NOT NULL default 'iso-8859-1',
	  text_encoding varchar(20) NOT NULL default 'us-ascii',
	  show_summary char(3) NOT NULL default 'YES',
	  summary_type varchar(4) NOT NULL default 'HTML',
	  require_send_key char(3) NOT NULL default 'NO',
	  send_key varchar(255) NOT NULL default 'qwertyuiop',
	  users_per_page int(11) NOT NULL default '20',
	  mail_digests_phpbb_path varchar(255) NOT NULL default './',
	  PRIMARY KEY  (table_key)
	) TYPE=MyISAM COMMENT='Digest Settings Table'";

	if ( !($result = $db->sql_query($sql)))
	{
		message_die(GENERAL_ERROR, 'Unable to create '. DIGEST_SETTINGS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
	}

	// Insert the one row required in the digest settings table
	$sql = 'INSERT INTO ' . DIGEST_SETTINGS_TABLE . ' (table_key) VALUES (1)'; 
	if ( !($result = $db->sql_query($sql)))
	{
		message_die(GENERAL_ERROR, 'Unable to insert row into '. DIGEST_SETTINGS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
	}

}

if (($major_version == 1) && ($minor_version == 0) && (($micro_version == 17) || ($micro_version == 18)))
{
	// Update the version number
	$sql = 'UPDATE ' . DIGEST_SETTINGS_TABLE . " SET version = '1.0.19'";
	if ( !($result = $db->sql_query($sql)))
	{
		message_die(GENERAL_ERROR, 'Error updating ' . DIGEST_SUBSCRIPTIONS_TABLE . ' table', '', __LINE__, __FILE__, $sql);
	}
}

?>
<html>
<head>
<title>Digest Upgrade Database</title>
</head>
<body> 
<p>If you see this message, then your database should be upgraded to support the latest digest features.</p> 
<p>If you are all done, please delete this file and remove the install directory, since your forum will not be accessible until it is removed.</p> 
</body>
</html>
